@@ -3,21 +3,22 @@
 #' @aliases SDMXConcept,SDMXConcept-method
 #' 
 #' @usage
-#' SDMXConcept(xmlObj)
+#' SDMXConcept(xmlObj, namespaces)
 #' 
 #' @param xmlObj object of class "XMLInternalDocument derived from XML package
+#' @param namespaces object of class "data.frame" given the list of namespace URIs
 #' @return an object of class "SDMXConcept"
 #' 
 #' @seealso \link{readSDMX}
 #'
-SDMXConcept <- function(xmlObj){
+SDMXConcept <- function(xmlObj, namespaces){
 
-  sdmxVersion <- version.SDMXSchema(xmlDoc(xmlObj))
-  VERSION.21 <- sdmxVersion == "2.1"
-  
-  namespaces <- namespaces.SDMX(xmlDoc(xmlObj))
   messageNs <- findNamespace(namespaces, "message")
   strNs <- findNamespace(namespaces, "structure")
+  
+  sdmxVersion <- version.SDMXSchema(xmlDoc(xmlObj), namespaces)
+  VERSION.21 <- sdmxVersion == "2.1"
+  
   refNs <- strNs
   if(VERSION.21){
     comNs <- findNamespace(namespaces, "common")
